SWDEV-474617 - Add Peer Device access check for memcpy2D tests and fix for SVM Memory test.

Change-Id: Idff7c02087f99c59f456e0027bbe0bc19cf67059
This commit is contained in:
Rahul Manocha
2024-08-01 16:38:58 -07:00
committed by Rakesh Roy
parent 56ef43810b
commit 8b15996041
2 changed files with 19 additions and 14 deletions
@@ -234,16 +234,19 @@ void launch_kernels_and_verify(std::vector<hipStream_t> &streams, unsigned int n
* - HIP_VERSION >= 5.7
*/
TEST_CASE("test_svm_fine_grain_memory_consistency") {
int pcieAtomic = 0;
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
if (!pcieAtomic) {
fprintf(stderr, "Device doesn't support pcie atomic, Skipped\n");
REQUIRE(true);
return;
}
const int num_elements = 2167;
int num_devices = 0;
HIP_CHECK(hipGetDeviceCount(&num_devices));
for(int id = 0; id < num_devices; id++) {
int pcieAtomic = 0;
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, id));
if (!pcieAtomic) {
fprintf(stderr, "Device doesn't support pcie atomic, Skipped\n");
REQUIRE(true);
return;
}
}
const int num_elements = 2167;
std::vector<hipStream_t> streams(num_devices);
for (int d = 0; d < num_devices; d++) {